==> what-is-new-webpack2-1.0.3.tgz: package/whatsnew.js <==
import { createClient } from "contentful";
import { format, parseISO } from "date-fns";
import "./styles.css";

export class WhatsNew {
  constructor(name, appName) {
    console.log("NAME IS " + name + " APP NAME IS :: " + appName);
    this.client = createClient({
      space: "ix8eqmh7slbd",
      accessToken: "VGat13fNbeGyZvBDRQA_dLB-kalAxoQ4VPLfiU4zhOI",
    });
  }

  async getMessages(limit = 6, skip = 0) {
    try {
      // Pagination
      const response = await this.client.getEntries({
        content_type: "page",
        limit,
        skip,
      });
      let messages = response.items;

      messages = messages.map((item) => {
        const { id, createdAt } = item.sys;
        const { title, description, userName, scheduledFor } = item.fields;
        const featuerImage = item.fields.featureImage.fields.file.url;

        return {
          id,
          title,
          featuerImage,
          userName,
          description,
          createdAt,
          scheduledFor,
        };
      });
      return messages;
    } catch (err) {
      console.log(err);
    }
  }

  async render() {
    const messages = await this.getMessages();

    let outHtml = `
    <div class="overlay" id="wp">
    <div class="dialog">

      <div class="l-btn">
                        <button class="button-58" id="hRead">I have read this information</button>
                    </div>
    ${messages.map((message) => `${this.renderMessage(message)}`).join("\n")}
    
   
                       <div class="dialog__footer "> </div>
    </div></div>`;

    this.myFragment = document.createRange().createContextualFragment(outHtml);
    document.body.appendChild(this.myFragment);

    // return
  }

  renderMessage(message) {
    return `
 <div class="dialog__title">
                    <h2>${message.title}</h2>
                 
            </div>
<div class="date">Document Date : ${format(
      parseISO(message.scheduledFor),
      "PPP"
    )}</div>
  <div class="dialog__content cont">
  <div>
  ${message.description}
</div>

     <div class="author-image">
                                <img src="${message.featuerImage}" alt="" />
    </div>

  </div>`;
  }

  afterRender() {
    const close = document.getElementById("hRead");
    if (close) {
      close.addEventListener("click", () => {
        const test = document.getElementById("wp");
        document.body.removeChild(test);
      });
    }
  }

  close() {
    const test = document.getElementById("wp");
    test.style.display = "none";
  }
}

//const client = createClient({
//   space: "ix8eqmh7slbd",
//   accessToken: "VGat13fNbeGyZvBDRQA_dLB-kalAxoQ4VPLfiU4zhOI",
// });

// export const getMessages = async (limit = 6, skip = 0) => {
//   try {
//     // Pagination
//     const response = await client.getEntries({
//       content_type: "page",
//       limit,
//       skip,
//     });
//     let messages = response.items;

//     messages = messages.map((item) => {
//       const { id, createdAt } = item.sys;
//       const { title, description, userName, scheduledFor } = item.fields;
//       const featuerImage = item.fields.featureImage.fields.file.url;

//       return {
//         id,
//         title,
//         featuerImage,
//         userName,
//         description,
//         createdAt,
//         scheduledFor,
//       };
//     });
//     console.log("RETURN" + messages);
//     return messages;
//   } catch (err) {
//     console.log(err);
//   }
// };

// export const MessageScreen = {
//   render: async () => {
//     const messages = await getMessages();

//     return `
//     <div class="overlay" id="wp">
//     <div class="dialog">
//     <div class="dialog__content cont">
//     ${messages.map((message) => `${Message.render(message)}`).join("\n")}
//     <div>
//     <div class="blog-layout container" id="blog-layout">
//     </div>
//     <div class="load-btn"><button class="load" id="load" onclick='close()'>Load more</button></div>
//     <div class="l-btn"><button class="ld" id="hRead" >I have read</button></div>
//     </div></div></div></div>`;
//   },
//   afterRender: () => {
//     const close = document.getElementById("hRead");
//     if (close) {
//       close.addEventListener("click", () => {
//         const test = document.getElementById("wp");
//         test.style.display = "none";
//       });
//     }
//   },
//   close: () => {
//     const test = document.getElementById("wp");
//     //test.parentNode.removeChild(elem);
//     test.style.display = "none";
//   },
// };

// export const Message = {
//   render: (message) => {
//     return `
//     <div class="blog">
//     <div class="blog-text">
//     <h2>${message.title}
//     </h2>
//     <div class="d-flex">
//     <div class="category">${message.description}</div>
//     <div class="date">${format(parseISO(message.scheduledFor), "PPP")}</div>
//     </div>
//     <div class="author d-flex">
//     <div class="author-image">
//     <img src="${message.featuerImage}" alt="" />
//     </div>
//     <div class="author-name">${message.userName}</div>
//     </div>
//     </div>
//     </div>`;
//   },
// };

==> what-is-new-webpack2-1.0.6.tgz: package/whatsnew.js <==
import { createClient } from "contentful";
import { format, parseISO } from "date-fns";
import "./styles.css";

export class WhatsNew {
  constructor(name, appName) {
    console.log("NAME IS " + name + " APP NAME IS :: " + appName);
    this.client = createClient({
      space: "ix8eqmh7slbd",
      accessToken: "VGat13fNbeGyZvBDRQA_dLB-kalAxoQ4VPLfiU4zhOI",
    });
  }

  async getMessages(limit = 6, skip = 0) {
    try {
      // Pagination
      const response = await this.client.getEntries({
        content_type: "page",
        limit,
        skip,
      });
      let messages = response.items;

      messages = messages.map((item) => {
        const { id, createdAt } = item.sys;
        const { title, description, userName, scheduledFor } = item.fields;
        const featuerImage = item.fields.featureImage.fields.file.url;

        return {
          id,
          title,
          featuerImage,
          userName,
          description,
          createdAt,
          scheduledFor,
        };
      });
      return messages;
    } catch (err) {
      console.log(err);
    }
  }

  async render() {
    const messages = await this.getMessages();

    let outHtml = `
    <div class="overlay" id="wp">
    <h2>What's New</div>
    <div class="dialog cont">

     
    ${messages.map((message) => `${this.renderMessage(message)}`).join("\n")}
    
   
                     <div class="l-btn">
                        <button class="button-58" id="hRead">I have read this information</button>
                    </div>
    </div></div>`;

    this.myFragment = document.createRange().createContextualFragment(outHtml);
    document.body.appendChild(this.myFragment);

    // return
  }

  renderMessage(message) {
    return `
 <div class="dialog__title">
                    <h2>${message.title}</h2>
                 
            </div>
<div class="date">Document Date : ${format(
      parseISO(message.scheduledFor),
      "PPP"
    )}</div>
  <div class="dialog__content ">
  <div>
  ${message.description}
</div>

     <div class="author-image">
                                <img src="${message.featuerImage}" alt="" />
    </div>

  </div>`;
  }

  afterRender() {
    const close = document.getElementById("hRead");
    if (close) {
      close.addEventListener("click", () => {
        const test = document.getElementById("wp");
        document.body.removeChild(test);
      });
    }
  }

  close() {
    const test = document.getElementById("wp");
    test.style.display = "none";
  }
}

//const client = createClient({
//   space: "ix8eqmh7slbd",
//   accessToken: "VGat13fNbeGyZvBDRQA_dLB-kalAxoQ4VPLfiU4zhOI",
// });

// export const getMessages = async (limit = 6, skip = 0) => {
//   try {
//     // Pagination
//     const response = await client.getEntries({
//       content_type: "page",
//       limit,
//       skip,
//     });
//     let messages = response.items;

//     messages = messages.map((item) => {
//       const { id, createdAt } = item.sys;
//       const { title, description, userName, scheduledFor } = item.fields;
//       const featuerImage = item.fields.featureImage.fields.file.url;

//       return {
//         id,
//         title,
//         featuerImage,
//         userName,
//         description,
//         createdAt,
//         scheduledFor,
//       };
//     });
//     console.log("RETURN" + messages);
//     return messages;
//   } catch (err) {
//     console.log(err);
//   }
// };

// export const MessageScreen = {
//   render: async () => {
//     const messages = await getMessages();

//     return `
//     <div class="overlay" id="wp">
//     <div class="dialog">
//     <div class="dialog__content cont">
//     ${messages.map((message) => `${Message.render(message)}`).join("\n")}
//     <div>
//     <div class="blog-layout container" id="blog-layout">
//     </div>
//     <div class="load-btn"><button class="load" id="load" onclick='close()'>Load more</button></div>
//     <div class="l-btn"><button class="ld" id="hRead" >I have read</button></div>
//     </div></div></div></div>`;
//   },
//   afterRender: () => {
//     const close = document.getElementById("hRead");
//     if (close) {
//       close.addEventListener("click", () => {
//         const test = document.getElementById("wp");
//         test.style.display = "none";
//       });
//     }
//   },
//   close: () => {
//     const test = document.getElementById("wp");
//     //test.parentNode.removeChild(elem);
//     test.style.display = "none";
//   },
// };

// export const Message = {
//   render: (message) => {
//     return `
//     <div class="blog">
//     <div class="blog-text">
//     <h2>${message.title}
//     </h2>
//     <div class="d-flex">
//     <div class="category">${message.description}</div>
//     <div class="date">${format(parseISO(message.scheduledFor), "PPP")}</div>
//     </div>
//     <div class="author d-flex">
//     <div class="author-image">
//     <img src="${message.featuerImage}" alt="" />
//     </div>
//     <div class="author-name">${message.userName}</div>
//     </div>
//     </div>
//     </div>`;
//   },
// };
